@@ -2,21 +2,20 @@
 model_list_checks = function(model_list){
 
 
-  # check model form --------------------------------------
+  # check model form ----
 
   model_classes = lapply(model_list, class)
 
   # all same class
 
   if(length(unique(model_classes)) != 1){
-    stop('All models must be the same class, one of lm, glm, lmerMod, glmerMod, svyglm.')
+    stop('All models must be the same class, one of lm, glm.')
   }
 
-  # class one of lm, glm, lmerMod, glmerMod, svyglm
+  # class one of lm, glm
 
-  if(!(model_classes[[1]][1] %in%
-       c('lm', 'glm', 'lmerMod', 'glmerMod', 'svyglm'))){
-    stop('All models must be the same class, one of lm, glm, lmerMod, glmerMod, svyglm.')
+  if(!(model_classes[[1]][1] %in% c('lm', 'glm'))){
+    stop('All models must be the same class, one of lm, glm.')
   }
 
   # same family and link function
@@ -29,10 +28,10 @@ model_list_checks = function(model_list){
   }
 
 
-  # check same covariates in same order -------------------
+  # check same covariates in same order ----
 
-  for(j in 2:length(model_list)){
-    for(k in 1:(length(model_list) - 1)){
+  for(j in 1:(length(model_list) - 1)){
+    for(k in (j + 1):length(model_list)){
       if(!all(names(get_coefs(model_list[[j]])) == names(get_coefs(model_list[[k]]))))
       {stop('Models must share same predictors in same order.')}
     }
